==> gazpacho-0.5.0.tar.bz2: Gazpacho-0.5.0/gazpacho/files.py <==
files = ['/usr/bin/gazpacho',
'/usr/share/applications/gazpacho.desktop',
'/usr/share/gazpacho/pixmaps/optionmenu.png',
'/usr/share/gazpacho/pixmaps/statusbar.png',
'/usr/share/gazpacho/pixmaps/notebook.png',
'/usr/share/gazpacho/pixmaps/curve.png',
'/usr/share/gazpacho/pixmaps/checkbutton.png',
'/usr/share/gazpacho/pixmaps/hseparator.png',
'/usr/share/gazpacho/pixmaps/spinbutton.png',
'/usr/share/gazpacho/pixmaps/toolbar.png',
'/usr/share/gazpacho/pixmaps/colorselectiondialog.png',
'/usr/share/gazpacho/pixmaps/hbuttonbox.png',
'/usr/share/gazpacho/pixmaps/accellabel.png',
'/usr/share/gazpacho/pixmaps/treeview.png',
'/usr/share/gazpacho/pixmaps/menu.png',
'/usr/share/gazpacho/pixmaps/button.png',
'/usr/share/gazpacho/pixmaps/image.png',
'/usr/share/gazpacho/pixmaps/label.png',
'/usr/share/gazpacho/pixmaps/table.png',
'/usr/share/gazpacho/pixmaps/togglebutton.png',
'/usr/share/gazpacho/pixmaps/gammacurve.png',
'/usr/share/gazpacho/pixmaps/expander.png',
'/usr/share/gazpacho/pixmaps/combo.png',
'/usr/share/gazpacho/pixmaps/progressbar.png',
'/usr/share/gazpacho/pixmaps/gazpacho-icon.png',
'/usr/share/gazpacho/pixmaps/frame.png',
'/usr/share/gazpacho/pixmaps/messagedialog.png',
'/usr/share/gazpacho/pixmaps/calendar.png',
'/usr/share/gazpacho/pixmaps/gazpacho.png',
'/usr/share/gazpacho/pixmaps/vseparator.png',
'/usr/share/gazpacho/pixmaps/arrow.png',
'/usr/share/gazpacho/pixmaps/fontselection.png',
'/usr/share/gazpacho/pixmaps/inputdialog.png',
'/usr/share/gazpacho/pixmaps/colorselection.png',
'/usr/share/gazpacho/pixmaps/scrolledwindow.png',
'/usr/share/gazpacho/pixmaps/layout.png',
'/usr/share/gazpacho/pixmaps/fontselectiondialog.png',
'/usr/share/gazpacho/pixmaps/textview.png',
'/usr/share/gazpacho/pixmaps/hruler.png',
'/usr/share/gazpacho/pixmaps/selector.png',
'/usr/share/gazpacho/pixmaps/menubar.png',
'/usr/share/gazpacho/pixmaps/hbox.png',
'/usr/share/gazpacho/pixmaps/vbox.png',
'/usr/share/gazpacho/pixmaps/hpaned.png',
'/usr/share/gazpacho/pixmaps/window.png',
'/usr/share/gazpacho/pixmaps/handlebox.png',
'/usr/share/gazpacho/pixmaps/fileselection.png',
'/usr/share/gazpacho/pixmaps/vscrollbar.png',
'/usr/share/gazpacho/pixmaps/entry.png',
'/usr/share/gazpacho/pixmaps/viewport.png',
'/usr/share/gazpacho/pixmaps/radiobutton.png',
'/usr/share/gazpacho/pixmaps/vscale.png',
'/usr/share/gazpacho/pixmaps/hscrollbar.png',
'/usr/share/gazpacho/pixmaps/vpaned.png',
'/usr/share/gazpacho/pixmaps/vruler.png',
'/usr/share/gazpacho/pixmaps/fixed.png',
'/usr/share/gazpacho/pixmaps/eventbox.png',
'/usr/share/gazpacho/pixmaps/dialog.png',
'/usr/share/gazpacho/pixmaps/drawingarea.png',
'/usr/share/gazpacho/pixmaps/vbuttonbox.png',
'/usr/share/gazpacho/pixmaps/hscale.png',
'/usr/share/gazpacho/pixmaps',
'/usr/share/gazpacho/catalogs/gtk+.xml',
'/usr/share/gazpacho/catalogs',
'/usr/share/gazpacho',
'/usr/share/locale/pt_BR/LC_MESSAGES/gazpacho.mo',
'/usr/share/locale/fr/LC_MESSAGES/gazpacho.mo',
'/usr/share/locale/gl_ES/LC_MESSAGES/gazpacho.mo',
'/usr/share/locale/es/LC_MESSAGES/gazpacho.mo',
'/usr/lib/python2.3/site-packages/gazpacho/loader/proxy.py',
'/usr/lib/python2.3/site-packages/gazpacho/loader/widgettree.py',
'/usr/lib/python2.3/site-packages/gazpacho/loader/__init__.py',
'/usr/lib/python2.3/site-packages/gazpacho/loader/tags.py',
'/usr/lib/python2.3/site-packages/gazpacho/loader/proxy.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/loader/widgettree.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/loader/__init__.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/loader/tags.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/loader',
'/usr/lib/python2.3/site-packages/gazpacho/cursor.py',
'/usr/lib/python2.3/site-packages/gazpacho/property.py',
'/usr/lib/python2.3/site-packages/gazpacho/path.py',
'/usr/lib/python2.3/site-packages/gazpacho/palette.py',
'/usr/lib/python2.3/site-packages/gazpacho/choice.py',
'/usr/lib/python2.3/site-packages/gazpacho/clipboard.py',
'/usr/lib/python2.3/site-packages/gazpacho/command.py',
'/usr/lib/python2.3/site-packages/gazpacho/widgettreeview.py',
'/usr/lib/python2.3/site-packages/gazpacho/widget.py',
'/usr/lib/python2.3/site-packages/gazpacho/gladegtk.py',
'/usr/lib/python2.3/site-packages/gazpacho/util.py',
'/usr/lib/python2.3/site-packages/gazpacho/main.py',
'/usr/lib/python2.3/site-packages/gazpacho/__init__.py',
'/usr/lib/python2.3/site-packages/gazpacho/widgetregistry.py',
'/usr/lib/python2.3/site-packages/gazpacho/application.py',
'/usr/lib/python2.3/site-packages/gazpacho/project.py',
'/usr/lib/python2.3/site-packages/gazpacho/l10n.py',
'/usr/lib/python2.3/site-packages/gazpacho/widgetclass.py',
'/usr/lib/python2.3/site-packages/gazpacho/signaleditor.py',
'/usr/lib/python2.3/site-packages/gazpacho/gaction.py',
'/usr/lib/python2.3/site-packages/gazpacho/placeholder.py',
'/usr/lib/python2.3/site-packages/gazpacho/popup.py',
'/usr/lib/python2.3/site-packages/gazpacho/propertyclass.py',
'/usr/lib/python2.3/site-packages/gazpacho/editor.py',
'/usr/lib/python2.3/site-packages/gazpacho/parameter.py',
'/usr/lib/python2.3/site-packages/gazpacho/catalog.py',
'/usr/lib/python2.3/site-packages/gazpacho/uieditor.py',
'/usr/lib/python2.3/site-packages/gazpacho/cursor.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/property.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/path.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/palette.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/choice.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/clipboard.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/command.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/widgettreeview.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/widget.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/gladegtk.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/util.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/main.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/__init__.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/widgetregistry.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/application.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/project.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/l10n.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/widgetclass.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/signaleditor.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/gaction.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/placeholder.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/popup.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/propertyclass.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/editor.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/parameter.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/catalog.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/uieditor.pyc',
'/usr/lib/python2.3/site-packages/gazpacho']

==> gazpacho-0.5.1.tar.bz2: Gazpacho-0.5.1/gazpacho/files.py <==
files = ['/usr/bin/gazpacho',
'/usr/share/applications/gazpacho.desktop',
'/usr/share/gazpacho/pixmaps/optionmenu.png',
'/usr/share/gazpacho/pixmaps/statusbar.png',
'/usr/share/gazpacho/pixmaps/notebook.png',
'/usr/share/gazpacho/pixmaps/curve.png',
'/usr/share/gazpacho/pixmaps/checkbutton.png',
'/usr/share/gazpacho/pixmaps/hseparator.png',
'/usr/share/gazpacho/pixmaps/spinbutton.png',
'/usr/share/gazpacho/pixmaps/toolbar.png',
'/usr/share/gazpacho/pixmaps/alignment.png',
'/usr/share/gazpacho/pixmaps/colorselectiondialog.png',
'/usr/share/gazpacho/pixmaps/hbuttonbox.png',
'/usr/share/gazpacho/pixmaps/accellabel.png',
'/usr/share/gazpacho/pixmaps/treeview.png',
'/usr/share/gazpacho/pixmaps/menu.png',
'/usr/share/gazpacho/pixmaps/button.png',
'/usr/share/gazpacho/pixmaps/image.png',
'/usr/share/gazpacho/pixmaps/label.png',
'/usr/share/gazpacho/pixmaps/table.png',
'/usr/share/gazpacho/pixmaps/togglebutton.png',
'/usr/share/gazpacho/pixmaps/gammacurve.png',
'/usr/share/gazpacho/pixmaps/expander.png',
'/usr/share/gazpacho/pixmaps/combo.png',
'/usr/share/gazpacho/pixmaps/progressbar.png',
'/usr/share/gazpacho/pixmaps/gazpacho-icon.png',
'/usr/share/gazpacho/pixmaps/frame.png',
'/usr/share/gazpacho/pixmaps/messagedialog.png',
'/usr/share/gazpacho/pixmaps/calendar.png',
'/usr/share/gazpacho/pixmaps/gazpacho.png',
'/usr/share/gazpacho/pixmaps/vseparator.png',
'/usr/share/gazpacho/pixmaps/arrow.png',
'/usr/share/gazpacho/pixmaps/fontselection.png',
'/usr/share/gazpacho/pixmaps/inputdialog.png',
'/usr/share/gazpacho/pixmaps/colorselection.png',
'/usr/share/gazpacho/pixmaps/scrolledwindow.png',
'/usr/share/gazpacho/pixmaps/layout.png',
'/usr/share/gazpacho/pixmaps/fontselectiondialog.png',
'/usr/share/gazpacho/pixmaps/textview.png',
'/usr/share/gazpacho/pixmaps/hruler.png',
'/usr/share/gazpacho/pixmaps/selector.png',
'/usr/share/gazpacho/pixmaps/menubar.png',
'/usr/share/gazpacho/pixmaps/hbox.png',
'/usr/share/gazpacho/pixmaps/vbox.png',
'/usr/share/gazpacho/pixmaps/hpaned.png',
'/usr/share/gazpacho/pixmaps/window.png',
'/usr/share/gazpacho/pixmaps/handlebox.png',
'/usr/share/gazpacho/pixmaps/fileselection.png',
'/usr/share/gazpacho/pixmaps/vscrollbar.png',
'/usr/share/gazpacho/pixmaps/entry.png',
'/usr/share/gazpacho/pixmaps/viewport.png',
'/usr/share/gazpacho/pixmaps/radiobutton.png',
'/usr/share/gazpacho/pixmaps/vscale.png',
'/usr/share/gazpacho/pixmaps/hscrollbar.png',
'/usr/share/gazpacho/pixmaps/vpaned.png',
'/usr/share/gazpacho/pixmaps/vruler.png',
'/usr/share/gazpacho/pixmaps/comboentry.png',
'/usr/share/gazpacho/pixmaps/fixed.png',
'/usr/share/gazpacho/pixmaps/eventbox.png',
'/usr/share/gazpacho/pixmaps/dialog.png',
'/usr/share/gazpacho/pixmaps/drawingarea.png',
'/usr/share/gazpacho/pixmaps/vbuttonbox.png',
'/usr/share/gazpacho/pixmaps/hscale.png',
'/usr/share/gazpacho/pixmaps',
'/usr/share/gazpacho/catalogs/gtk+.xml',
'/usr/share/gazpacho/catalogs',
'/usr/share/gazpacho',
'/usr/share/locale/ca/LC_MESSAGES/gazpacho.mo',
'/usr/share/locale/pt_BR/LC_MESSAGES/gazpacho.mo',
'/usr/share/locale/fr/LC_MESSAGES/gazpacho.mo',
'/usr/share/locale/gl_ES/LC_MESSAGES/gazpacho.mo',
'/usr/share/locale/es/LC_MESSAGES/gazpacho.mo',
'/usr/lib/python2.3/site-packages/gazpacho/loader/proxy.py',
'/usr/lib/python2.3/site-packages/gazpacho/loader/widgettree.py',
'/usr/lib/python2.3/site-packages/gazpacho/loader/__init__.py',
'/usr/lib/python2.3/site-packages/gazpacho/loader/compat.py',
'/usr/lib/python2.3/site-packages/gazpacho/loader/tags.py',
'/usr/lib/python2.3/site-packages/gazpacho/loader/proxy.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/loader/widgettree.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/loader/__init__.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/loader/compat.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/loader/tags.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/loader',
'/usr/lib/python2.3/site-packages/gazpacho/cursor.py',
'/usr/lib/python2.3/site-packages/gazpacho/property.py',
'/usr/lib/python2.3/site-packages/gazpacho/palette.py',
'/usr/lib/python2.3/site-packages/gazpacho/choice.py',
'/usr/lib/python2.3/site-packages/gazpacho/clipboard.py',
'/usr/lib/python2.3/site-packages/gazpacho/command.py',
'/usr/lib/python2.3/site-packages/gazpacho/widgettreeview.py',
'/usr/lib/python2.3/site-packages/gazpacho/widget.py',
'/usr/lib/python2.3/site-packages/gazpacho/gladegtk.py',
'/usr/lib/python2.3/site-packages/gazpacho/util.py',
'/usr/lib/python2.3/site-packages/gazpacho/main.py',
'/usr/lib/python2.3/site-packages/gazpacho/__init__.py',
'/usr/lib/python2.3/site-packages/gazpacho/widgetregistry.py',
'/usr/lib/python2.3/site-packages/gazpacho/application.py',
'/usr/lib/python2.3/site-packages/gazpacho/project.py',
'/usr/lib/python2.3/site-packages/gazpacho/l10n.py',
'/usr/lib/python2.3/site-packages/gazpacho/widgetclass.py',
'/usr/lib/python2.3/site-packages/gazpacho/signaleditor.py',
'/usr/lib/python2.3/site-packages/gazpacho/gaction.py',
'/usr/lib/python2.3/site-packages/gazpacho/placeholder.py',
'/usr/lib/python2.3/site-packages/gazpacho/popup.py',
'/usr/lib/python2.3/site-packages/gazpacho/propertyclass.py',
'/usr/lib/python2.3/site-packages/gazpacho/editor.py',
'/usr/lib/python2.3/site-packages/gazpacho/parameter.py',
'/usr/lib/python2.3/site-packages/gazpacho/files.py',
'/usr/lib/python2.3/site-packages/gazpacho/catalog.py',
'/usr/lib/python2.3/site-packages/gazpacho/uieditor.py',
'/usr/lib/python2.3/site-packages/gazpacho/cursor.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/property.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/palette.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/choice.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/clipboard.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/command.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/widgettreeview.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/widget.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/gladegtk.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/util.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/main.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/__init__.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/widgetregistry.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/application.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/project.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/l10n.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/widgetclass.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/signaleditor.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/gaction.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/placeholder.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/popup.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/propertyclass.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/editor.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/parameter.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/files.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/catalog.pyc',
'/usr/lib/python2.3/site-packages/gazpacho/uieditor.pyc',
'/usr/lib/python2.3/site-packages/gazpacho']
